@@ -258,12 +258,12 @@ QWindow *UnlockApp::getActiveScreen()
     return activeScreen;
 }
 
-void UnlockApp::loadWallpaperPlugin(KQuickAddons::QuickViewSharedEngine *view)
+KDeclarative::QmlObjectSharedEngine *UnlockApp::loadWallpaperPlugin(KQuickAddons::QuickViewSharedEngine *view)
 {
     auto package = m_wallpaperIntegration->package();
     if (!package.isValid()) {
         qCWarning(KSCREENLOCKER_GREET) << "Error loading the wallpaper, no valid package loaded";
-        return;
+        return nullptr;
     }
 
     auto qmlObject = new KDeclarative::QmlObjectSharedEngine(view);
@@ -277,17 +277,31 @@ void UnlockApp::loadWallpaperPlugin(KQuickAddons::QuickViewSharedEngine *view)
             qCWarning(KSCREENLOCKER_GREET) << "Wallpaper needs to be a QtQuick Item";
             return;
         }
-        item->setParentItem(view->rootObject());
-        item->setZ(-1000);
-
-        // set anchors
-        QQmlExpression expr(qmlObject->engine()->rootContext(), item, QStringLiteral("parent"));
-        QQmlProperty prop(item, QStringLiteral("anchors.fill"));
-        prop.write(expr.evaluate());
 
         view->rootContext()->setContextProperty(QStringLiteral("wallpaper"), item);
         view->rootContext()->setContextProperty(QStringLiteral("wallpaperIntegration"), m_wallpaperIntegration);
     });
+    return qmlObject;
+}
+
+void UnlockApp::setWallpaperItemProperties(KDeclarative::QmlObjectSharedEngine *wallpaperObject, KQuickAddons::QuickViewSharedEngine *view)
+{
+    if (!wallpaperObject) {
+        return;
+    }
+
+    auto item = qobject_cast<QQuickItem *>(wallpaperObject->rootObject());
+    if (!item) {
+        qCWarning(KSCREENLOCKER_GREET) << "Wallpaper needs to be a QtQuick Item";
+        return;
+    }
+    item->setParentItem(view->rootObject());
+    item->setZ(-1000);
+
+    // set anchors
+    QQmlExpression expr(wallpaperObject->engine()->rootContext(), item, QStringLiteral("parent"));
+    QQmlProperty prop(item, QStringLiteral("anchors.fill"));
+    prop.write(expr.evaluate());
 }
 
 void UnlockApp::initialViewSetup()
@@ -327,9 +341,11 @@ KQuickAddons::QuickViewSharedEngine *UnlockApp::createViewForScreen(QScreen *scr
         view->setGeometry(geo);
     });
 
-    // first create KDeclarative, to be sure that it created a KIO Network Factory
-    KDeclarative::KDeclarative::setupEngine(view->engine());
     view->engine()->rootContext()->setContextObject(new KLocalizedContext(view->engine()));
+    auto oldFactory = view->engine()->networkAccessManagerFactory();
+    view->engine()->setNetworkAccessManagerFactory(nullptr);
+    delete oldFactory;
+    view->engine()->setNetworkAccessManagerFactory(new NoAccessNetworkAccessManagerFactory);
 
     if (!m_testing) {
         if (QX11Info::isPlatformX11()) {
@@ -363,7 +379,7 @@ KQuickAddons::QuickViewSharedEngine *UnlockApp::createViewForScreen(QScreen *scr
     context->setContextProperty(QStringLiteral("defaultToSwitchUser"), m_defaultToSwitchUser);
     context->setContextProperty(QStringLiteral("config"), m_lnfIntegration->configuration());
 
-    loadWallpaperPlugin(view);
+    auto wallpaperObj = loadWallpaperPlugin(view);
     if (auto object = view->property("wallpaperGraphicsObject").value<KDeclarative::QmlObjectSharedEngine *>()) {
         // initialize with our size to avoid as much resize events as possible
         object->completeInitialization({
@@ -384,11 +400,9 @@ KQuickAddons::QuickViewSharedEngine *UnlockApp::createViewForScreen(QScreen *scr
     }
     view->setResizeMode(KQuickAddons::QuickViewSharedEngine::SizeRootObjectToView);
 
-    // overwrite the factory set by kdeclarative
-    auto oldFactory = view->engine()->networkAccessManagerFactory();
-    view->engine()->setNetworkAccessManagerFactory(nullptr);
-    delete oldFactory;
-    view->engine()->setNetworkAccessManagerFactory(new NoAccessNetworkAccessManagerFactory);
+    // we need to set this wallpaper properties separately after the lockscreen QML is loaded
+    // this is because we need to anchor to the view that gets loaded
+    setWallpaperItemProperties(wallpaperObj, view);
 
     QQmlProperty lockProperty(view->rootObject(), QStringLiteral("locked"));
     lockProperty.write(m_immediateLock || (!m_noLock && !m_delayedLockTimer));
@@ -739,5 +753,3 @@ void UnlockApp::updateCanHibernate()
 }
 
 } // namespace
-
-#include "greeterapp.moc"
